@@ -24,8 +24,10 @@ POP     *   p;
     register int        i;
 
     /*  Unmark all the messages */
-    for (i = p->msg_count, mp = p->mlp; i > 0; i--, mp++)
+    for (i = p->msg_count, mp = p->mlp; i > 0; i--, mp++) {
         mp->del_flag = FALSE; 
+        mp->retr_flag = mp->orig_retr_state; 
+    }
     
     /*  Reset the messages-deleted and bytes-deleted counters */
     p->msgs_deleted = 0;
